<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ZoomOut</name>
    <message>
        <location filename="../ZoomOutInit.js" line="+2"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddálit</translation>
    </message>
</context>
</TS>
